==> ms_general_utils-2.0.15-py3-none-any.whl: ms_utils/authentication.py <==
from functools import wraps

from flask import g, current_app, request

from ms_utils import abort_bad_request, abort_unauthorized, request_get, abort_forbidden
from ms_utils.function_utils import get_hierarchy_users_list


class NotAuthenticate(object):
    """
    Not Authentication Class
    """

    def dispatch_request(self, **kwargs):
        user = None
        try:
            response = request_get(f'{current_app.config.get("AUTH_MS_API")}/auth/check-authentication')
            if response.status_code == 200:
                user = response.json()['data']
        except Exception:
            pass
        g.setdefault('user', user)
        return super(NotAuthenticate, self).dispatch_request(**kwargs)


class IsAuthenticate(object):
    """
    Is Authenticate Class
    """

    def dispatch_request(self, **kwargs):
        config = current_app.config
        if not config.get('AUTH_MS_API'):
            abort_bad_request('The authentication API (AUTH_MS_API) is not configured')

        response = request_get(f'{current_app.config.get("AUTH_MS_API")}/auth/check-authentication')
        if not response.status_code == 200:
            abort_unauthorized()
        g.setdefault('user', response.json()['data'])
        return super(IsAuthenticate, self).dispatch_request(**kwargs)


class HasHierarchy(object):
    """
    Has Hierarchy Class

    Class to verify users has a hierarchy, in that case modify a get_queryset method
    """
    config = current_app.config
    hierarchy_field = config.get('HIERARCHY_PAYLOAD_FIELD')
    hierarchy_api = config.get('HIERARCHY_PAYLOAD_API')
    hierarchy_users_list = []

    def handle_validations(self):
        if not self.hierarchy_field:
            abort_bad_request('The hierarchy field (HIERARCHY_PAYLOAD_FIELD) is not configured')

        if not self.hierarchy_api:
            abort_bad_request('The hierarchy api (HIERARCHY_PAYLOAD_API) is not configured')

        if not self.config.get('AUTH_MS_API'):
            abort_bad_request('The authentication API (AUTH_MS_API) is not configured')

    def get_queryset(self):
        queryset = super(HasHierarchy, self).get_queryset()
        payload_value = request.args.get(self.hierarchy_field)
        if payload_value and payload_value in self.hierarchy_users_list:
            return queryset.filter_by(**{self.hierarchy_field: payload_value})
        condition = getattr(self.model, self.hierarchy_field).in_(self.hierarchy_users_list)
        queryset = queryset.filter_by(condition)
        return queryset

    def dispatch_request(self, **kwargs):
        self.handle_validations()

        self.hierarchy_users_list = get_hierarchy_users_list()

        if self.hierarchy_field in request.args or 'id' not in request.view_args:
            payload_value = request.args.get(self.hierarchy_field)
            arg_value = request.view_args.get('id')
            if (payload_value in self.hierarchy_users_list or
                    arg_value in self.hierarchy_users_list or arg_value == g.get('user')['id']):
                return super(HasHierarchy, self).dispatch_request(**kwargs)
            abort_forbidden("You do not have permission for this request")

        return super(HasHierarchy, self).dispatch_request(**kwargs)


def validate_permission(permission_required=None, permission_type="api"):
    if permission_required is None:
        abort_forbidden("You do not have permission for this request")

    config = current_app.config
    if not config.get('AUTH_MS_API'):
        abort_bad_request('The authentication API (AUTH_MS_API) is not configured')
    if not config.get('APP_NAME'):
        abort_bad_request('The app name (APP_NAME) is not configured')
    if not (isinstance(permission_required, tuple)
            or isinstance(permission_required, list)
            or isinstance(permission_required, set)):
        abort_bad_request('The permission_required variable must be iterable')
    response = request_get(f'{current_app.config.get("AUTH_MS_API")}/user-rol-permission/me', params={
        'not_paginate': True,
        'permission_type': permission_type,
        'app': config.get('APP_NAME')
    })
    if not response.status_code == 200:
        abort_unauthorized()
    permissions = response.json()['data']
    for permission in permission_required:
        if not any(permission == p['permission'] for p in permissions):
            abort_forbidden("You do not have permission for this request")
    return True


class ApiPermission(object):
    """
    Api Permission Class
    """
    permission_required = None
    permission_type = 'api'

    def dispatch_request(self, **kwargs):
        validate_permission(self.permission_required, self.permission_type)
        return super(ApiPermission, self).dispatch_request(**kwargs)


def view_decorator(func):
    def decorator(view_func):
        @wraps(view_func)
        def _wrapped_view(*args, **kwargs):
            if func():
                return view_func(*args, **kwargs)
            abort_forbidden()

        return _wrapped_view

    return decorator


def permission_decorator(permissions):
    def check_perms():
        if isinstance(permissions, str):
            perms = (permissions,)
        else:
            perms = permissions
        return validate_permission(permissions)

    return view_decorator(check_perms)

==> ms_general_utils-2.0.17-py3-none-any.whl: ms_utils/authentication.py <==
from functools import wraps

from flask import g, current_app, request

from ms_utils import abort_bad_request, abort_unauthorized, request_get, abort_forbidden
from ms_utils.function_utils import get_hierarchy_users_list


class NotAuthenticate(object):
    """
    Not Authentication Class
    """

    def dispatch_request(self, **kwargs):
        user = None
        try:
            response = request_get(f'{current_app.config.get("AUTH_MS_API")}/auth/check-authentication')
            if response.status_code == 200:
                user = response.json()['data']
        except Exception:
            pass
        g.setdefault('user', user)
        return super(NotAuthenticate, self).dispatch_request(**kwargs)


class IsAuthenticate(object):
    """
    Is Authenticate Class
    """

    def dispatch_request(self, **kwargs):
        config = current_app.config
        if not config.get('AUTH_MS_API'):
            abort_bad_request('The authentication API (AUTH_MS_API) is not configured')

        response = request_get(f'{current_app.config.get("AUTH_MS_API")}/auth/check-authentication')
        if not response.status_code == 200:
            abort_unauthorized()
        g.setdefault('user', response.json()['data'])
        return super(IsAuthenticate, self).dispatch_request(**kwargs)


class HasHierarchy(object):
    """
    Has Hierarchy Class

    Class to verify users has a hierarchy, in that case modify a get_queryset method
    """
    config = None
    hierarchy_field = None
    hierarchy_api = None
    hierarchy_users_list = []

    def handle_init_vars(self):
        # Init vars
        self.config = current_app.config
        self.hierarchy_field = self.config.get('HIERARCHY_PAYLOAD_FIELD')
        self.hierarchy_api = self.config.get('HIERARCHY_PAYLOAD_API')

    def handle_validations(self):
        if not self.hierarchy_field:
            abort_bad_request('The hierarchy field (HIERARCHY_PAYLOAD_FIELD) is not configured')

        if not self.hierarchy_api:
            abort_bad_request('The hierarchy api (HIERARCHY_PAYLOAD_API) is not configured')

        if not self.config.get('AUTH_MS_API'):
            abort_bad_request('The authentication API (AUTH_MS_API) is not configured')

    def get_queryset(self):
        queryset = super(HasHierarchy, self).get_queryset()
        payload_value = request.args.get(self.hierarchy_field)
        if payload_value and payload_value in self.hierarchy_users_list:
            return queryset.filter_by(**{self.hierarchy_field: payload_value})
        self.hierarchy_users_list.push(g.get('user')['id'])
        condition = getattr(self.model, self.hierarchy_field).in_(self.hierarchy_users_list)
        queryset = queryset.filter(condition)
        return queryset

    def dispatch_request(self, **kwargs):
        self.handle_init_vars()

        self.handle_validations()

        self.hierarchy_users_list = get_hierarchy_users_list()

        if self.hierarchy_field in request.args or 'id' in request.view_args:
            payload_value = request.args.get(self.hierarchy_field)
            arg_value = request.view_args.get('id')
            if (payload_value in self.hierarchy_users_list or
                    arg_value in self.hierarchy_users_list or arg_value == g.get('user')['id']):
                return super(HasHierarchy, self).dispatch_request(**kwargs)
            abort_forbidden("You do not have permission for this request")

        return super(HasHierarchy, self).dispatch_request(**kwargs)


def validate_permission(permission_required=None, permission_type="api"):
    if permission_required is None:
        abort_forbidden("You do not have permission for this request")

    config = current_app.config
    if not config.get('AUTH_MS_API'):
        abort_bad_request('The authentication API (AUTH_MS_API) is not configured')
    if not config.get('APP_NAME'):
        abort_bad_request('The app name (APP_NAME) is not configured')
    if not (isinstance(permission_required, tuple)
            or isinstance(permission_required, list)
            or isinstance(permission_required, set)):
        abort_bad_request('The permission_required variable must be iterable')
    response = request_get(f'{current_app.config.get("AUTH_MS_API")}/user-rol-permission/me', params={
        'not_paginate': True,
        'permission_type': permission_type,
        'app': config.get('APP_NAME')
    })
    if not response.status_code == 200:
        abort_unauthorized()
    permissions = response.json()['data']
    for permission in permission_required:
        if not any(permission == p['permission'] for p in permissions):
            abort_forbidden("You do not have permission for this request")
    return True


class ApiPermission(object):
    """
    Api Permission Class
    """
    permission_required = None
    permission_type = 'api'

    def dispatch_request(self, **kwargs):
        validate_permission(self.permission_required, self.permission_type)
        return super(ApiPermission, self).dispatch_request(**kwargs)


def view_decorator(func):
    def decorator(view_func):
        @wraps(view_func)
        def _wrapped_view(*args, **kwargs):
            if func():
                return view_func(*args, **kwargs)
            abort_forbidden()

        return _wrapped_view

    return decorator


def permission_decorator(permissions):
    def check_perms():
        if isinstance(permissions, str):
            perms = (permissions,)
        else:
            perms = permissions
        return validate_permission(permissions)

    return view_decorator(check_perms)
